==> enterprisemodules-zfs_appliance-1.2.1.tar.gz: enterprisemodules-zfs_appliance-1.2.1/lib/puppet/type/zfs_project.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/zfs/core'

module Puppet
  #
  Type.newtype(:zfs_project) do
    include Puppet_X::EnterpriseModules::Zfs::Type

    desc <<-EOD
      This type allows you to manage a project on a ZFS appliance.

      Here is an example on how to use this:

          zfs_project { 'default:all/project_1':
            ensure              => 'present',
            aclinherit          => 'restricted',
            aclmode             => 'discard',
            checksum            => 'fletcher4',
            compression         => 'off',
            default_group       => 'other',
            default_permissions => '705',
            default_user        => 'nobody',
            mountpoint          => '/export/project_1',
            quota               => '0.0',
            recordsize          => '131072.0',
            reservation         => '0.0',
            sharenfs            => 'on',
            sharesmb            => 'on',
            snapdir             => 'hidden',
          }

    EOD

    restfull_path('/api/storage/v1/pools/%{pool_name}/projects')
    restfull_type('projects')

    ensurable
    parameter :project_name
    parameter :appliance
    parameter :name
    parameter :pool_name
    parameter :maxblocksize

    property :aclinherit
    property :aclmode
    property :atime
    property :checksum
    property :compression
    property :mountpoint
    property :quota
    property :readonly
    property :recordsize
    property :reservation
    property :sharesmb
    property :sharenfs
    property :snapdir
    property :sharedav
    property :shareftp
    property :sharesftp
    property :sharetftp
    property :default_group
    property :default_permissions
    property :default_sparse
    property :default_user

    add_title_attributes(:pool_name, :project_name) do
       /^((.*:)?(.*)\/(.*))$/
    end

    #
    # Autorequire the appliance
    #
    autorequire(:zfs_appliance)  { appliance }

  end
end

==> enterprisemodules-zfs_appliance-1.3.0.tar.gz: enterprisemodules-zfs_appliance-1.3.0/lib/puppet/type/zfs_project.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/zfs/core'
# rubocop:disable Style/Documentation
module Puppet
  # rubocop:enable Style/Documentation
  Type.newtype(:zfs_project) do
    include Puppet_X::EnterpriseModules::Zfs::Type

    desc <<-DESC
      This type allows you to manage a project on a ZFS appliance.

      Here is an example on how to use this:

          zfs_project { 'default:all/project_1':
            ensure              => 'present',
            aclinherit          => 'restricted',
            aclmode             => 'discard',
            checksum            => 'fletcher4',
            compression         => 'off',
            default_group       => 'other',
            default_permissions => '705',
            default_user        => 'nobody',
            mountpoint          => '/export/project_1',
            quota               => '0.0',
            recordsize          => '131072.0',
            reservation         => '0.0',
            sharenfs            => 'on',
            sharesmb            => 'on',
            snapdir             => 'hidden',
          }

    DESC

    restfull_path('/api/storage/v1/pools/%<pool_name>s/projects')
    restfull_type('projects')

    ensurable
    parameter :project_name
    parameter :appliance
    parameter :name
    parameter :pool_name
    parameter :maxblocksize

    property :aclinherit
    property :aclmode
    property :atime
    property :checksum
    property :compression
    property :mountpoint
    property :quota
    property :readonly
    property :recordsize
    property :reservation
    property :sharesmb
    property :sharenfs
    property :snapdir
    property :sharedav
    property :shareftp
    property :sharesftp
    property :sharetftp
    property :default_group
    property :default_permissions
    property :default_sparse
    property :default_user

    add_title_attributes(:pool_name, :project_name) do
      %r{^((.*:)?(.*)/(.*))$}
    end

    #
    # Autorequire the appliance
    #
    autorequire(:zfs_appliance) { appliance }
  end
end
